Package: PatientProfiles
Type: Package
Title: Identify Characteristics of Patients in the OMOP Common Data
        Model
Version: 1.6.0
Authors@R: c(
    person("Martí", "Català", , "marti.catalasabate@ndorms.ox.ac.uk", 
    role = c("aut", "cre"), comment = c(ORCID = "0000-0003-3308-9905")),
    person("Yuchen", "Guo", , "yuchen.guo@ndorms.ox.ac.uk", role = c("aut"),
    comment = c(ORCID = "0000-0002-0847-4855")),
    person("Mike", "Du", , "mike.du@ndorms.ox.ac.uk", role = c("aut"), 
    comment = c(ORCID = "0000-0002-9517-8834")),
    person("Kim", "Lopez-Guell", , "kim.lopez@spc.ox.ac.uk", role = c("aut"),
    comment = c(ORCID = "0000-0002-8462-8668")),
    person("Edward", "Burn", , "edward.burn@ndorms.ox.ac.uk", role = c("aut"),
    comment = c(ORCID = "0000-0002-9286-1128")),
    person("Nuria", "Mercade-Besora", , "nuria.mercadebesora@ndorms.ox.ac.uk", 
    role = c("aut"), comment = c(ORCID = "0009-0006-7948-3747")),
    person("Xintong", "Li", , "xintong.li@ndorms.ox.ac.uk", role = c("ctb"),
    comment = c(ORCID = "0000-0002-6872-5804")),
    person("Xihang", "Chen", , "xihang.chen@ndorms.ox.ac.uk", role = c("ctb"),
    comment = c(ORCID = "0009-0001-8112-8959"))
    )
Maintainer: Martí Català <marti.catalasabate@ndorms.ox.ac.uk>
Description: Identify the characteristics of patients in data mapped to the 
    Observational Medical Outcomes Partnership (OMOP) common data model.
License: Apache License (>= 2)
Encoding: UTF-8
Suggests: bit64, CDMConnector (>= 1.3.1), CodelistGenerator,
        CohortConstructor, covr, DBI, dbplyr, DT, duckdb (>= 0.9.0),
        ggplot2, glue, gt, here, Hmisc, knitr, odbc, omock (>= 0.7.0),
        patchwork, rmarkdown, RPostgres, scales, spelling, testthat (>=
        3.1.5), tictoc, withr
Imports: cli, clock, dplyr, lifecycle, omopgenerics (>= 1.3.1), purrr,
        rlang, stringr, tidyr
URL: https://darwin-eu.github.io/PatientProfiles/
BugReports: https://github.com/darwin-eu/PatientProfiles/issues
Language: en-US
Depends: R (>= 4.1.0)
Config/testthat/edition: 3
Config/testthat/parallel: true
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-25 09:31:44 UTC; martics
Author: Martí Català [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3308-9905>),
  Yuchen Guo [aut] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Mike Du [aut] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Kim Lopez-Guell [aut] (ORCID: <https://orcid.org/0000-0002-8462-8668>),
  Edward Burn [aut] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Nuria Mercade-Besora [aut] (ORCID:
    <https://orcid.org/0009-0006-7948-3747>),
  Xintong Li [ctb] (ORCID: <https://orcid.org/0000-0002-6872-5804>),
  Xihang Chen [ctb] (ORCID: <https://orcid.org/0009-0001-8112-8959>)
Repository: CRAN
Date/Publication: 2026-07-25 11:30:02 UTC
Built: R 4.5.2; ; 2026-07-25 15:03:16 UTC; unix
